#  petname: library for generating human-readable, random names
#           for objects (e.g. hostnames, containers, blobs)
#
#  Copyright 2014 Dustin Kirkland <dustin.kirkland@gmail.com>
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


import random

adverbs = ["abandonedly", "abasedly", "abashedly", "abatedly", "abatingly", "abbreviatedly", "aberrantly", "abeyantly", "abhorrently", "abidingly", "abjectly", "ably", "abnormally", "abominably", "abortedly", "about", "abrasively", "abruptly", "absently", "absentmindedly", "absolutely", "absorbantly", "absorbedly", "absorbingly", "abstainedly", "abstentiously", "abstinently", "abstractedly", "abstractly", "abstrusely", "absurdly", "abundantly", "abusedly", "abusively", "abysmally", "academically", "acapella", "acceptingly", "accessibly", "accidentally", "acclamatorily", "accommodatingly", "accomplishedly", "accordingly", "accurately", "accusatorily", "accusingly", "accustomably", "acerbically", "achingly", "acidly", "acknowledgingly", "acquiescently", "acquisitively", "acridly", "acrimoniously", "acrobatically", "actively", "actually", "acutely", "adamantly", "addictedly", "addictively", "additionally", "adeptly", "adequately", "adherently", "adhesively", "adjacently", "admirably", "admiringly", "admonishedly", "admonishingly", "adorably", "adoringly", "adroitly", "adulatingly", "adulterously", "advantageously", "adventurously", "adversarially", "adversely", "aesthetically", "affably", "affectedly", "affectingly", "affectionately", "affirmatively", "affirmingly", "affrontedly", "after", "afterwards", "again", "agape", "agedly", "agelessly", "aggravatedly", "aggravatingly", "aggressively", "aggrievedly", "aghastly", "agilely", "agitatedly", "agonisedly", "agonizedly", "agreeably", "agreeingly", "aimlessly", "airily", "alarmedly", "alarmingly", "alertly", "allegorically", "alliteratively", "alludingly", "alluringly", "allusively", "almost", "alone", "aloofly", "aloud", "already", "also", "alternatingly", "alternatively", "altruistically", "always", "amateurishly", "amatively", "amazedly", "ambiguously", "ambitiously", "ambivalently", "amblingly", "ambrosially", "amenably", "amiably", "amicably", "amorally", "amorously", "amply", "amuck", "amusedly", "amusingly", "analytically", "anarchically", "anciently", "anew", "angelically", "angrily", "anguishedly", "angularly", "animalistically", "animatedly", "annoyedly", "annoyingly", "annually", "answeringly", "antagonistically", "anticipatingly", "anticipatorily", "anticlimactically", "antisocially", "anxiously", "anyway", "apart", "apathetically", "apodeictically", "apologetically", "appalledly", "apparently", "appealingly", "appeasedly", "appeasingly", "appositely", "appraisingly", "appreciatively", "apprehensibly", "apprehensively", "appropriately", "approvingly", "approximately", "aptly", "aquatically", "arbitrarily", "arcanely", "archly", "ardently", "arduously", "argumentatively", "aridly", "aristocratically", "aromatically", "around", "arousedly", "arousingly", "arrantly", "arrogantly", "artfully", "articulately", "artistically", "artlessly", "ascendingly", "ascetically", "ashamedly", "aside", "asininely", "askance", "askew", "aspiringly", "assentingly", "assertively", "assessingly", "assiduously", "assimilatedly", "assimilatingly", "assumingly", "assuredly", "assuringly", "astonishedly", "astoundedly", "astringently", "astuciously", "astutely", "asunder", "asymmetrically", "athletically", "atrociously", "attemptingly", "attentively", "attractively", "atypically", "audaciously", "audibly", "augustly", "auspiciously", "austerely", "authoritatively", "autocratically", "automatically", "autonomously", "avariciously", "avidly", "away", "awedly", "awesomely", "awestruckly", "awfully", "awhile", "awkwardly", "axiomatically", "back", "backhandedly", "backward", "backwardly", "backwards", "badly", "baffledly", "bafflingly", "balancedly", "balancingly", "baldly", "balefully", "balletically", "ballistically", "banally", "banefully", "banteringly", "barbarically", "barbarously", "barefacedly", "barefootedly", "barely", "basely", "bashfully", "basically", "bawdily", "beadily", "beamingly", "bearishly", "beatifically", "beauteously", "beautifully", "becalmingly", "beckoningly", "becomingly", "bedraggledly", "befittingly", "beforehand", "befuddledly", "begrudgingly", "beguilingly", "belatedly", "believably", "believingly", "bellicosely", "belligerently", "bemusedly", "beneficently", "beneficially", "benevolently", "benignantly", "benignly", "bent", "berserkly", "beseechingly", "besottedly", "bestially", "better", "bewilderedly", "bewilderingly", "bewitchingly", "biasedly", "bibulously", "biliously", "billowingly", "bitchily", "bitingly", "bitterly", "bittersweetly", "bizarrely", "blackly", "blamelessly", "blandly", "blankly", "blasphemously", "blatantly", "blazingly", "bleakly", "blearily", "blessedly", "blindly", "blissfully", "blithely", "blithesomely", "blockedly", "bloodily", "bloodthirstily", "blotchily", "bluffly", "bluishly", "bluntly", "blurrily", "blushingly", "blusteringly", "boastfully", "boastingly", "bodily", "boilingly", "boisterously", "boldly", "bolsteringly", "bombastically", "bookishly", "boomingly", "boorishly", "bootlessly", "boozily", "boredly", "boringly", "bossily", "botheredly", "bothersomely", "bouncily", "boundingly", "boundlessly", "bountifully", "bovinely", "bowingly", "boyishly", "bracingly", "braggingly", "brashly", "brassily", "brattily", "bravely", "brazenly", "breakingly", "breathily", "breathlessly", "breathtakingly", "breezily", "briefly", "brightly", "brilliantly", "brimmingly", "briskly", "brittlely", "broadly", "brokenly", "broodingly", "brotherly", "bruisedly", "brusquely", "brutally", "brutishly", "bubblingly", "bulkily", "bullheadedly", "bullyingly", "bumblingly", "buoyantly", "burdenedly", "burdensomely", "burningly", "busily", "businesslike", "caddishly", "cagily", "cajolingly", "calculatingly", "callously", "callowly", "calmingly", "calmly", "calumniously", "candidly", "cannily", "cantankerously", "capably", "capriciously", "captiously", "captivatedly", "captivatingly", "carefully", "carelessly", "caressingly", "caringly", "carnally", "carnivorously", "casually", "casuistically", "catastrophically", "catatonically", "cattily", "caustically", "cautiously", "cavalierly", "ceaselessly", "celibately", "censoriously", "centrally", "ceremonially", "ceremoniously", "certainly", "chagrinedly", "challengingly", "chantingly", "chaotically", "characteristically", "charily", "charismatically", "charitably", "charmingly", "chastely", "chastenedly", "chattily", "chauvinistically", "cheekily", "cheerfully", "cheerily", "cheeringly", "cheerlessly", "cheesily", "cherishedly", "cherishingly", "cherubically", "chidingly", "childishly", "chillily", "chillingly", "chimingly", "chipperly", "chirpily", "chivalrously", "chokingly", "chronologically", "chubbily", "chunkily", "churlishly", "circuitously", "circularly", "circumspectly", "circumstantially", "civilly", "clairvoyantly", "clammily", "clandestinely", "clarifyingly", "clashingly", "classically", "classily", "classlessly", "clatteringly", "claustrophobically", "cleanly", "cleansingly", "clearer", "clearly", "cleverly", "climatically", "clingingly", "clinically", "clinkingly", "clockwise", "closely", "closer", "cloudily", "clubbily", "cluelessly", "clumsily", "coarsely", "coaxingly", "cockily", "cogently", "cognisantly", "cognizantly", "coherently", "coincidentally", "coldheartedly", "coldly", "collectedly", "collectively", "colorfully", "colorlessly", "colourfully", "colourlessly", "coltishly", "comatosely", "combatively", "comfortably", "comfortedly", "comfortingly", "comfortlessly", "comically", "commandingly", "commendatorily", "commodiously", "commonly", "communicatively", "compactly", "companionably", "comparatively", "comparingly", "compassionately", "compellingly", "compensatingly", "competently", "competitively", "complacently", "complainingly", "complaisantly", "complementarily", "completely", "complexly", "compliantly", "complicatedly", "complicitly", "complimentarily", "composedly", "comprehendingly", "comprehensibly", "compromisingly", "compulsively", "compulsorily", "concealingly", "concedingly", "conceitedly", "concentratedly", "concernedly", "concertedly", "conciliatorily", "concisely", "concludingly", "conclusively", "concupiscently", "concurrently", "concurringly", "condescendingly", "conditionally", "confidentially", "confidently", "confidingly", "confinedly", "confirmingly", "conflictedly", "confoundedly", "confusedly", "confusingly", "congenially", "congestedly", "congratulatorily", "congruently", "conjointly", "connately", "connivingly", "conscientiously", "consciously", "consecutively", "consensually", "consentedly", "consentingly", "consequently", "conservatively", "considerably", "considerately", "consideringly", "consistently", "consolingly", "conspicuously", "conspiratorially", "constantly", "constrictedly", "constrictingly", "constrictively", "constructively", "consumedly", "consumingly", "consummately", "contagiously", "contemplatively", "contemptibly", "contemptuously", "contentedly", "contentiously", "contently", "continently", "continually", "continuingly", "continuously", "contradictorily", "contrarily", "contrastingly", "contritely", "contrivedly", "controlledly", "contumaciously", "contumeliously", "conveniently", "conversationally", "conversely", "convincedly", "convincingly", "convivially", "convolutely", "convulsively", "coolingly", "coolly", "cooperatively", "coordinately", "copiously", "coquettishly", "cordially", "correctedly", "correctively", "correctly", "correspondingly", "cosily", "coughingly", "counterproductively", "courageously", "courteously", "covertly", "covetously", "cowardly", "coyly", "cozily", "crabbily", "craftily", "crankily", "crassly", "cravenly", "crazily", "creakily", "creamily", "creatively", "credulously", "creepily", "crescendingly", "crestfallenly", "cringingly", "crisply", "critically", "croakily", "croakingly", "crookedly", "crossingly", "crossly", "crowdedly", "crudely", "cruelly", "crunchily", "crushedly", "crushingly", "crustily", "cryptically", "cultivatedly", "culturedly", "cumbersomely", "cunningly", "curiously", "curmudgeonly", "cursorily", "curtly", "curvedly", "customarily", "cutely", "cuttingly", "cynically", "daffily", "daftly", "daily", "daintily", "damply", "dancingly", "dangerously", "dapperly", "daringly", "darkly", "dashingly", "dauntedly", "dauntingly", "dauntlessly", "dazedly", "dazzlingly", "deadpan", "deafeningly", "deafly", "dearly", "debasedly", "debonairly", "decadently", "deceitfully", "deceivingly", "decently", "deceptively", "decidedly", "decisively", "decoratively", "decorously", "decreasingly", "dedicatedly", "deductively", "deeper", "deeply", "defamatorily", "defeatedly", "defectingly", "defencelessly", "defenselessly", "defensively", "deferentially", "defiantly", "definitely", "deflatedly", "deflectingly", "deformedly", "deftly", "dejectedly", "delectably", "deliberately", "delicately", "deliciously", "delightedly", "delightfully", "deliriously", "deludedly", "demandingly", "dementedly", "demonstrably", "demonstratively", "demurely", "densely", "denunciatorily", "denyingly", "dependably", "dependantly", "dependently", "deplorably", "depravedly", "deprecatingly", "deprecatively", "depreciatorily", "depressedly", "depressingly", "derangedly", "derisively", "derivatively", "derogatively", "descendingly", "descriptively", "deservingly", "desirously", "desolately", "despairingly", "desperately", "despisingly", "despondently", "despotically", "destructively", "desultorily", "detachedly", "determinedly", "detrimentally", "devastatedly", "devastatingly", "devilishly", "deviously", "devotedly", "devotionally", "devoutly", "dexterously", "diabolically", "diagonally", "dictatorily", "didactically", "differently", "difficultly", "diffidently", "dignifiedly", "diligently", "diminutively", "dimly", "dimwittedly", "diplomatically", "directly", "direly", "dirtily", "disagreeably", "disagreeingly", "disappointedly", "disappointingly", "disapprovingly", "disarmingly", "disastrously", "disbelievingly", "discernibly", "discerningly", "discomfortingly", "discomposedly", "disconcertedly", "disconcertingly", "disconnectedly", "disconsolately", "discontentedly", "discordantly", "discouragingly", "discourteously", "discreetly", "discretely", "discretionally", "discriminatingly", "disdainfully", "disenchantedly", "disfavorably", "disgracefully", "disgruntledly", "disguisedly", "disgustedly", "disgustingly", "disharmoniously", "disheartenedly", "disheveledly", "dishonestly", "dishonorably", "disillusionedly", "disingenuously", "disinterestedly", "disjointedly", "dismally", "dismayedly", "dismayingly", "dismissively", "disobediently", "disobligingly", "disorganizedly", "disorientedly", "disparagingly", "dispassionately", "dispiritedly", "displeasedly", "disproportionally", "disproportionately", "disquietedly", "disquietingly", "disquietly", "disrespectfully", "disruptively", "dissatisfiedly", "dissentingly", "dissimilarly", "dissolutely", "dissonantly", "dissuasively", "distantly", "distastefully", "distemperately", "distinctively", "distinctly", "distinguishedly", "distractedly", "distractingly", "distraughtly", "distressedly", "distrustfully", "distrustingly", "disturbedly", "disturbingly", "ditzily", "divertedly", "divertingly", "dividedly", "divinely", "dizzily", "dizzyingly", "docilely", "dodgily", "doggedly", "dogmatically", "dolefully", "dolorously", "domestically", "dominantly", "domineeringly", "dotingly", "doubly", "doubtfully", "doubtingly", "doubtlessly", "doughtily", "dourly", "downcastly", "downheartedly", "downtroddenly", "downward", "downwardly", "draconially", "draftily", "drainedly", "dramatically", "drastically", "drawlingly", "dreadfully", "dreadingly", "dreamily", "dreamlessly", "drearily", "drenchedly", "drolly", "droopily", "drowsily", "drunkenly", "dryly", "dubiously", "duely", "dulcetly", "dully", "dumbfoundedly", "dumbly", "duplicitously", "duskily", "dustily", "duteously", "dutifully", "dwindlingly", "dynamically", "eagerly", "earnestly", "earsplittingly", "easily", "eastward", "eastwardly", "ebulliently", "eccentrically", "echoingly", "economically", "ecstatically", "edaciously", "edgily", "educationally", "eerily", "effectively", "effeminately", "effervescently", "effetely", "efficaciously", "efficiently", "effortfully", "effortlessly", "effusively", "egotistically", "elaborately", "elatedly", "elegantly", "eloquently", "elsewhere", "elusively", "emaciatedly", "embarrassedly", "embitteredly", "emotionally", "emotionlessly", "empathetically", "emphatically", "emptily", "enamouredly", "enchantedly", "enchantingly", "encompassingly", "encouragedly", "encouragingly", "endearingly", "endlessly", "energetically", "engagedly", "engagingly", "engrossedly", "enigmatically", "enjoyably", "enlightenedly", "enormously", "enquiringly", "enragedly", "enrapturedly", "ensuingly", "enterprisingly", "entertainedly", "entertainingly", "enthralledly", "enthrallingly", "enthusedly", "enthusiastically", "enticingly", "entirely", "entrancedly", "entrancingly", "entreatingly", "enviably", "enviously", "epigrammatically", "epithetically", "equally", "equivocally", "erectly", "erratically", "erroneously", "eruditely", "esoterically", "especially", "esuriently", "eternally", "ethereally", "euphemistically", "euphoniously", "euphorically", "evaluatingly", "evanescently", "evasively", "even", "evenly", "eventually", "everywhere", "evidently", "evilly", "evocatively", "exactingly", "exactly", "exaggeratedly", "exaltedly", "exasperatedly", "exasperatingly", "excellently", "exceptionally", "excessively", "excitedly", "excitingly", "exclusively", "excruciatingly", "excusingly", "exemplarily", "exhalingly", "exhaustedly", "exhaustively", "exhilaratedly", "exhilaratingly", "exigently", "exorbitantly", "exotically", "expansively", "expatiatingly", "expectantly", "experiencedly", "experimentally", "expertly", "explanatively", "explicitly", "exploratorily", "explosively", "expressionlessly", "expressively", "expressly", "exquisitely", "extemporaneously", "extemporarily", "extensively", "extortionately", "extraordinarily", "extravagantly", "extremely", "exuberantly", "exultantly", "exultingly", "facetiously", "facilely", "factually", "faintheartedly", "faintly", "fairly", "faithfully", "faithlessly", "fallaciously", "falsely", "falteringly", "familiarly", "famishedly", "famously", "fanatically", "fancifully", "fancily", "fantastically", "far", "farcically", "fascinatedly", "fashionably", "fast", "faster", "fastidiously", "fatalistically", "fatally", "fatefully", "fattily", "fatuously", "favorably", "favourably", "fawningly", "fearfully", "fearlessly", "fearsomely", "featherly", "fecklessly", "feebly", "feelingly", "feignedly", "felicitously", "femininely", "ferally", "ferociously", "fervently", "fervidly", "festively", "fetchingly", "fetidly", "feudally", "feverishly", "ficklely", "fiendishly", "fiercely", "figuratively", "filially", "filthily", "finally", "finely", "finickily", "finickingly", "firmly", "first", "firstly", "fishily", "fitfully", "fittingly", "fixatedly", "fixedly", "flabbergastedly", "flagrantly", "flakily", "flamboyantly", "flamingly", "flashily", "flashingly", "flatly", "flatteredly", "flatteringly", "flauntingly", "flavoressly", "flavorfully", "flavourfully", "flavourlessly", "flawlessly", "fleetingly", "flexibly", "flickeringly", "flightily", "flimsily", "flippantly", "flirtatiously", "flirtingly", "florally", "floridly", "flouncily", "flounderingly", "flourishingly", "floutingly", "flowingly", "fluctuatingly", "fluently", "fluffily", "fluidly", "flummoxedly", "flushedly", "flusteredly", "flutteringly", "focusedly", "foggily", "followingly", "fondly", "foolishly", "foppishly", "forbiddingly", "forcedly", "forcefully", "forcibly", "forebearingly", "forebodingly", "foreignly", "foreknowingly", "foresakenly", "foreseeingly", "foresightedly", "forgetfully", "forgivingly", "forlornly", "formally", "formidably", "formlessly", "forth", "forthcomingly", "forthrightly", "fortuitously", "fortunately", "forward", "forwardly", "foully", "foxily", "fractionally", "fractiously", "fragilely", "fragrantly", "frailly", "frankly", "frantically", "fraternally", "fraudulently", "frazzledly", "freakishly", "freely", "freezingly", "frenetically", "frenziedly", "frequently", "freshly", "fretfully", "friendlily", "frighfully", "frightenedly", "frighteningly", "frightfully", "frigidly", "friskily", "frivolously", "frolicsomely", "frontally", "frostily", "frothily", "frowningly", "frozenly", "frugally", "fruitfully", "fruitlessly", "frustratedly", "frustrately", "fully", "fulsomely", "fumblingly", "functionally", "funereally", "funnily", "furiously", "furrily", "further", "furthermore", "furtively", "fussily", "futilely", "fuzzily", "gaily", "gallantly", "gamely", "garbledly", "garishly", "garrulously", "gaspingly", "gaudily", "gawkishly", "geekily", "generally", "generously", "genially", "genteelly", "gently", "genuinely", "geographically", "germanely", "ghastly", "giddily", "gigantically", "gigglingly", "gingerly", "girlishly", "gladly", "glamorously", "glassily", "gleefully", "glibly", "glintingly", "glisteringly", "glitteringly", "gloatingly", "gloomily", "gloopily", "gloriously", "gloweringly", "glowingly", "glumly", "gluttonously", "goadingly", "goofily", "gorgeously", "gracefully", "gracelessly", "graciously", "gradually", "grammatically", "grandfatherly", "grandiloquently", "grandiosely", "grandly", "graphically", "gratefully", "gratifiedly", "gratifyingly", "gratingly", "gratuitously", "gravely", "greasily", "greatly", "greedily", "gregariously", "grimily", "grimly", "grindingly", "grinningly", "groaningly", "groggily", "gropingly", "grossly", "grotesquely", "grouchily", "growlingly", "grudgingly", "gruesomely", "gruffly", "grumblingly", "grumpily", "gruntingly", "guardedly", "guardingly", "guessingly", "guidingly", "guilefully", "guilelessly", "guiltily", "guiltlessly", "gullibly", "gurglingly", "gushingly", "gustily", "gutturally", "gymnastically", "habitually", "hackingly", "haggardly", "halfheartedly", "halfway", "haltingly", "hamfistedly", "handily", "handsomely", "haphazardly", "haplessly", "happily", "harassingly", "hard", "harder", "hardly", "harmfully", "harmlessly", "harmonically", "harmoniously", "harriedly", "harshly", "hastily", "hatefully", "haughtily", "hauntedly", "hauntingly", "hawkishly", "hazily", "headily", "headlong", "healthily", "heartbrokenly", "heartenedly", "heartfeltly", "heartily", "heartlessly", "heartrenderingly", "heartrendingly", "heatedly", "heavenly", "heavily", "hedonistically", "heedfully", "heedlessly", "heftily", "heinously", "hellishly", "helpfully", "helplessly", "heraldically", "heretically", "hermetically", "heroically", "hesitantly", "hesitatingly", "hiddenly", "hideously", "higher", "highly", "hilariously", "hintingly", "hissingly", "historically", "histrionically", "hoarsely", "hoggishly", "hollowly", "honestly", "honorably", "honoredly", "honourably", "honouredly", "hopefully", "hopelessly", "hopingly", "horizontally", "horribly", "horridly", "horrifically", "horrifiedly", "horrifyingly", "hospitably", "hostilely", "hotly", "hourly", "however", "hubristically", "huffily", "hugely", "huggingly", "humanely", "humbly", "humiliatedly", "humorlessly", "humorously", "humourlessly", "hungrily", "huntedly", "hurriedly", "hurtfully", "hurtly", "hushedly", "huskily", "hyperactively", "hypnotically", "hypocritically", "hypothetically", "hysterically", "icily", "idealistically", "identically", "idiosyncratically", "idiotically", "idly", "idolisingly", "idolizingly", "ignorantly", "illegibly", "illiberally", "illogically", "illuminatedly", "illustratively", "imaginatively", "imbalancedly", "imitatively", "immaculately", "immaturely", "immeasurably", "immediately", "immensely", "immoderately", "immodestly", "immovably", "immutably", "impalpably", "impartially", "impassively", "impatiently", "impeccably", "impededly", "imperatively", "imperceptibly", "imperfectly", "imperiously", "impersonally", "impertinently", "imperturbably", "impetuously", "impiously", "impishly", "implacably", "implausibly", "impliably", "implicitly", "imploringly", "impolitely", "importantly", "importunately", "importunely", "imposingly", "impotently", "imprecisely", "impressedly", "impressionably", "impressively", "improbably", "improperly", "improvidently", "improvisationally", "imprudently", "impudently", "impulsively", "impurely", "inaccurately", "inadequately", "inadvertently", "inanely", "inappropriately", "inaptly", "inarticulately", "inattentively", "inaudibly", "inauspiciously", "incapably", "incautiously", "incessantly", "incestuously", "incidentally", "inclusively", "incoherently", "incompetently", "incompletely", "incompliantly", "incomprehendingly", "incomprehensibly", "inconceivably", "inconclusively", "incongrously", "inconsequentially", "inconsequently", "inconsiderately", "inconsistently", "inconsolably", "inconspicuously", "inconveniently", "incoordinately", "incorrectly", "incorrigibly", "increasingly", "incredibly", "incredulously", "incrementally", "incurably", "incuriously", "indebtedly", "indecently", "indecisively", "indecorously", "indefinately", "indefinitely", "indelicately", "independently", "indeterminedly", "indicatively", "indifferently", "indignantly", "indirectly", "indiscernibly", "indiscreetly", "indiscriminately", "indiscriminatingly", "indistinctly", "individually", "indivisibly", "indolently", "indulgently", "industrially", "industriously", "inebriatedly", "ineffectively", "ineffectually", "inelegantly", "ineloquently", "ineptly", "inevitably", "inexactly", "inexcusably", "inexorably", "inexperiencedly", "inexpertly", "inexplicably", "inexpressively", "infatuatedly", "infectiously", "inflexibly", "influentially", "informally", "informatively", "infrequently", "infuriatingly", "ingeniously", "ingenuously", "ingratiatingly", "inhalingly", "inharmoniously", "inhospitably", "inhumanely", "inhumanly", "inimically", "iniquitously", "initially", "injudiciously", "injuredly", "innocently", "innocuously", "inoffensively", "inopportunely", "inordinately", "inquiringly", "inquisitively", "insanely", "insatiably", "inscrutably", "insecurely", "insensibly", "insensitively", "insidiously", "insightfully", "insignificantly", "insincerely", "insinuatingly", "insipidly", "insistently", "insolently", "insouciantly", "inspiredly", "inspiringly", "instantaneously", "instantly", "instead", "instinctively", "instinctually", "instructively", "insubordinately", "insubstantially", "insufferably", "insufficiently", "insultedly", "insultingly", "intangibly", "intangily", "intelligently", "intelligibly", "intemperately", "intensely", "intentionally", "intently", "interestedly", "interestingly", "interminably", "intermittently", "internally", "interrogatively", "intimately", "intimidatedly", "intimidatingly", "intolerantly", "intoxicatedly", "intoxicatingly", "intractably", "intransigently", "intrepidly", "intricately", "intriguedly", "intriguingly", "introductorily", "introspectively", "introvertedly", "intrusively", "intuitively", "inutilely", "invasively", "invectively", "inventively", "invigoratedly", "invigoratingly", "invitingly", "involuntarily", "inward", "inwardly", "inwards", "irascibly", "irately", "irenically", "irksomely", "ironhandedly", "ironically", "irrationally", "irregularly", "irrelevantly", "irreligiously", "irrepressibly", "irresistibly", "irresolutely", "irresponsibly", "irreverently", "irrevocably", "irritably", "irritatedly", "irritatingly", "isolatedly", "itchily", "jadedly", "jaggedly", "janglingly", "jarringly", "jauntily", "jazzily", "jealously", "jeeringly", "jejunely", "jerkily", "jestingly", "jocosely", "jocularly", "jointly", "jokingly", "jollily", "joltingly", "joshingly", "jovially", "joyfully", "joylessly", "joyously", "jubilantly", "judgementally", "judgmentally", "judiciously", "juicily", "jumpily", "just", "justifiedly", "justly", "keenly", "kiddingly", "kindheartedly", "kindly", "kinkily", "kissingly", "knavishly", "knottily", "knowingly", "knowledgeably", "kookily", "laboredly", "laboriously", "labouredly", "lachrymosely", "lackadaisically", "lacklustrely", "laconically", "ladylike", "lamely", "lamentingly", "languidly", "languishingly", "languorously", "lasciviously", "latently", "laterally", "lauditorily", "laughingly", "lavishly", "lawfully", "laxly", "lazily", "leadenly", "leadingly", "learnedly", "lecherously", "leerily", "leeringly", "left", "leftward", "leftwardly", "legalistically", "leisurely", "lengthily", "lengthwise", "leniently", "les", "less", "lethally", "lethargically", "levelly", "lewdly", "libelously", "liberally", "libidinously", "licentiously", "lifelessly", "lightfootedly", "lightheadedly", "lightheartedly", "lightly", "likely", "likewise", "liltingly", "limberly", "limitedly", "limpidly", "limply", "lingeringly", "linguistically", "lispily", "lispingly", "lissomely", "listlessly", "literally", "lithely", "lively", "lividly", "loathingly", "loftily", "logically", "lonesomely", "longingly", "loosely", "lopsidedly", "loquaciously", "lostly", "lots", "louder", "loudly", "lousily", "lovingly", "lower", "lowly", "loyally", "lucidly", "luckily", "ludicrously", "lugubriously", "lumberingly", "luminously", "luridly", "lushly", "lustfully", "lustily", "lustrelessly", "luxuriously", "lyrically", "macabrely", "maddeningly", "madly", "magisterially", "magnanimously", "magnificently", "magniloquently", "maidenly", "majestically", "malevolently", "maliciously", "malignantly", "malodorously", "manageably", "manfully", "maniacally", "manically", "manipulatedly", "manipulatively", "mannerly", "mannishly", "manually", "marginally", "markedly", "martially", "marvelously", "masculinely", "masochistically", "massively", "masterfully", "materialistically", "maternally", "mathematically", "matronly", "maturely", "mawkishly", "meanderingly", "meaningfully", "meaninglessly", "meaningly", "meanly", "meanwhile", "measuredly", "measuringly", "mechanically", "meddlesomely", "medicinally", "meditatively", "meekly", "melancholically", "mellifluously", "mellowly", "melodically", "melodiously", "melodramatically", "memorisingly", "menacingly", "mendaciously", "mentally", "mercifully", "mercilessly", "mercurially", "merely", "merrily", "mesmerizedly", "mesmerizingly", "messily", "metallically", "metaphorically", "methodically", "meticulously", "middlingly", "mightily", "mildly", "militantly", "militaristically", "mimickingly", "minaciously", "mincingly", "mindfully", "mindlessly", "minimally", "minisculely", "minutely", "mirthfully", "mirthlessly", "mischievously", "miserably", "misgivingly", "misguidingly", "misleadingly", "mistakenly", "mistily", "mistrustfully", "mistrustingly", "mnemonically", "mockingly", "moderately", "modestly", "moistly", "mollifiedly", "momentarily", "momentously", "monosyllabically", "monotonically", "monotonously", "monstrously", "monthly", "monumentally", "moodily", "mopingly", "morally", "morbidly", "mordaciously", "mordantly", "more", "moronically", "morosely", "mortally", "mortifiedly", "mostly", "motherly", "motionlessly", "motivatedly", "mournfully", "mousily", "movingly", "muddledly", "muffledly", "mulishly", "mullishly", "mumblingly", "mundanely", "munificently", "murderously", "murkily", "murmuringly", "muscularly", "mushily", "musically", "musingly", "mutedly", "mutely", "mutinously", "mutteringly", "mysteriously", "mystically", "mystifiedly", "naggingly", "naively", "nakedly", "narcissistically", "narrowly", "nasally", "nastily", "nationalistically", "natively", "nattily", "naturally", "naughtily", "nauseatedly", "nauseatingly", "nauseously", "nearer", "nearly", "neatly", "nebulously", "necessarily", "needfully", "needily", "needingly", "needlessly", "nefariously", "negatively", "neglectedly", "neglectfully", "negligently", "nervelessly", "nervously", "neurotically", "neutrally", "never", "next", "nicely", "niggardly", "nigglingly", "nimbly", "nobly", "noddingly", "noiselessly", "noisily", "noisomely", "nonchalantly", "noncommittally", "noncompetitively", "noncompliantly", "nonetheless", "nonjudgmentally", "nonplussedly", "nonsensically", "nonverbally", "normally", "northeastwardly", "northward", "northwardly", "northwestwardly", "nosily", "nostalgically", "not", "notably", "noticeably", "now", "noxiously", "nudely", "numbly", "numinously", "nuttily", "oafishly", "oathfully", "obdurately", "obediently", "obeisantly", "objectively", "obligatorily", "obligedly", "obligingly", "obliquely", "obliviously", "obnoxiously", "obscenely", "obscurely", "obsequiously", "observantly", "observingly", "obsessively", "obstinately", "obstreperously", "obtrusively", "obtusely", "obviously", "occasionally", "occupiedly", "oddly", "odorously", "off", "offendedly", "offensively", "offhandedly", "officially", "officiously", "often", "oilily", "ominously", "once", "onerously", "only", "onward", "onwardly", "onwards", "openhandedly", "openly", "operosely", "opinionatedly", "opportunely", "opportunistically", "opposedly", "oppositely", "oppressively", "optimally", "optimistically", "oracularly", "orderingly", "orderly", "ordinarily", "organizationally", "organizedly", "organizingly", "ornamentally", "ornately", "ornerily", "orthodoxly", "ostensibly", "ostentatiously", "otherwise", "out", "outlandishly", "outragedly", "outrageously", "outrightly", "outspokenly", "outward", "outwardly", "outwards", "overbearingly", "overconfidently", "overeagerly", "overenthusiastically", "overhead", "overmuch", "overprotectively", "overtly", "overwhelmedly", "overwhelmingly", "overzealously", "owlishly", "oxymoronically", "painedly", "painfully", "painlessly", "painstakingly", "palely", "paler", "pallidly", "panickingly", "pantingly", "paradoxically", "parallel", "paranoidly", "parenthetically", "parochially", "parsimoniously", "partially", "particularly", "partingly", "partly", "partway", "passably", "passingly", "passionately", "passionlessly", "passively", "past", "patently", "paternally", "pathetically", "patiently", "patriarchally", "patriotically", "patronisingly", "patronizingly", "pausingly", "peaceably", "peacefully", "peculiarly", "pedantically", "peevedly", "peevishly", "pejoratively", "pellucidly", "penetratingly", "penitentially", "penitently", "pensively", "penultimately", "perceptibly", "perceptively", "percussively", "peremptorily", "perfectly", "perfidiously", "perfunctorily", "periodically", "peripherally", "perkily", "permissively", "perpendicularly", "perpetually", "perplexedly", "perseveringly", "persistently", "personally", "perspicaciously", "perspicuously", "perspiringly", "persuadedly", "persuasively", "pertinaciously", "pertinently", "pertly", "perturbedly", "perversely", "pervertedly", "pessimistically", "pesteringly", "pestiferously", "petrifiedly", "pettishly", "petulantly", "philosophically", "phlegmatically", "physically", "pickily", "picturesquely", "piercingly", "pietistically", "piggishly", "piously", "piquantly", "piteously", "pithily", "pitifully", "pitilessly", "pityingly", "pivotally", "placatingly", "placidly", "plainly", "plaintively", "plangently", "platitudinously", "platonically", "plausibly", "playfully", "pleadingly", "pleasantly", "pleasedly", "pleasingly", "pleasurably", "plentifully", "pliantly", "pluckily", "poetically", "poignantly", "pointblank", "pointedly", "pointlessly", "poisedly", "poisonously", "pokingly", "polishedly", "politely", "politically", "poltroonishly", "pompously", "ponderingly", "ponderously", "pontifically", "poorly", "portentously", "positively", "possessively", "possibly", "potentially", "potently", "poutily", "powerfully", "powerlessly", "practically", "practicedly", "practisedly", "pragmatically", "prayerfully", "precariously", "preciously", "precipitately", "precipitously", "precisely", "precociously", "precognizantly", "predatorily", "predictably", "predictively", "preferentially", "prejudgementally", "prejudicedly", "preliminarily", "prematurely", "preoccupiedly", "preparatorily", "preparedly", "preposterously", "presentably", "presently", "pressingly", "pressuringly", "presumingly", "presumptively", "presumptuously", "pretentiously", "prettily", "preventively", "previously", "pridefully", "priggishly", "primarily", "primitively", "primly", "prissily", "pristinely", "privately", "proactively", "probably", "probingly", "problematically", "proceedingly", "processionally", "proddingly", "prodigally", "productively", "profanely", "professionally", "proficiently", "profligately", "profoundly", "profusely", "prognostically", "prognosticatively", "progressively", "prohibitively", "prolifically", "prolongedly", "prominently", "promiscuously", "promisingly", "promptingly", "promptly", "properly", "prophetically", "propitiatingly", "propitiously", "proprietarily", "prosaically", "prosily", "prospectively", "protectively", "protestingly", "protractedly", "proudly", "providently", "provincially", "provisionally", "provocatively", "prudently", "prudishly", "pruriently", "pryingly", "puckishly", "puerilely", "puffily", "pugnaciously", "puissantly", "pulchritudinously", "pulsatively", "punctiliously", "punctually", "pungently", "punishingly", "punitively", "puppyishly", "purely", "puritanically", "purposefully", "purposelessly", "purposely", "pursuingly", "pushily", "pusillanimously", "putridly", "puzzledly", "quaintly", "quakingly", "quarrelsomely", "quaveringly", "queasily", "queerly", "quellingly", "querulously", "queryingly", "questionably", "questioningly", "quicker", "quickly", "quiescently", "quietly", "quintessentially", "quirkily", "quiveringly", "quixotically", "quizzically", "rabidly", "racily", "radiantly", "raggedly", "ragingly", "railingly", "rakishly", "ramblingly", "rambunctiously", "rancidly", "rancorously", "randily", "randomly", "rankly", "rantingly", "rapidly", "raptly", "rapturously", "rarely", "rashly", "raspily", "raspingly", "rationally", "rattlingly", "raucously", "raunchily", "ravenously", "ravishingly", "readily", "realisingly", "realistically", "realizingly", "really", "reasonably", "reasonlessly", "reassuredly", "reassuringly", "rebelliously", "rebukingly", "recalcitrantly", "recallingly", "receptively", "reciprocatively", "recklessly", "reclusively", "recollectively", "recordingly", "red", "reddeningly", "redundantly", "reelingly", "refinedly", "reflectively", "reflexively", "refreshedly", "refreshingly", "regally", "regardfully", "regardless", "regardlessly", "regretfully", "regularly", "reinforcingly", "rejectedly", "rejoicingly", "relatedly", "relaxedly", "relaxingly", "relentingly", "relentlessly", "relevantly", "reliably", "relievedly", "relievingly", "religiously", "relishingly", "reluctantly", "remarkably", "remedially", "rememberingly", "reminiscently", "remonstrantly", "remorsefully", "remorselessly", "remotely", "renewedly", "repeatedly", "repellently", "repentantly", "repetitiously", "repetitively", "reprehensively", "repressedly", "reprimandingly", "reproachfully", "reprovingly", "repulsedly", "repulsively", "resentfully", "reservedly", "resignedly", "resolutely", "resolvedly", "resonantly", "resoundingly", "respectably", "respectfully", "respectively", "resplendently", "responsibly", "responsively", "restfully", "restively", "restlessly", "restrainedly", "restrainingly", "restrictedly", "restrictively", "retaliatingly", "reticently", "retractively", "retributively", "retroactively", "retrospectively", "revealingly", "revengefully", "reverberantly", "reverently", "revoltingly", "revolutionarily", "rewardingly", "rhapsodically", "rhetorically", "rhythmically", "rhythmlessly", "ribaldly", "richly", "ridiculously", "right", "righteously", "rightfully", "rightward", "rightwardly", "rigidly", "rigorously", "ringingly", "riotously", "ripely", "risibly", "risquely", "ritualistically", "ritually", "robustly", "roguishly", "roisterously", "rollickingly", "rollingly", "romantically", "roomily", "rosily", "rottenly", "rotundly", "roughly", "roundly", "rousingly", "routinely", "rowdily", "royally", "rudely", "ruefully", "ruggedly", "rumblingly", "ruminatingly", "ruminatively", "rustily", "ruthlessly", "sacramentally", "sacredly", "sacrificially", "sacrilegiously", "saddenedly", "sadistically", "sadly", "safely", "sagaciously", "sagely", "salaciously", "saltily", "salutatorily", "sanctimoniously", "sanely", "sanguinely", "sappily", "sarcastically", "sardonically", "sartorially", "sassily", "satedly", "satirically", "satisfactorily", "satisfiedly", "satisfyingly", "saturatedly", "saturninely", "saucily", "savagely", "savoringly", "savouringly", "savvily", "scandalously", "scantily", "scantly", "scarcely", "scaredly", "scarily", "scathingly", "scatteredly", "sceptically", "schemingly", "scholastically", "scientifically", "scintillatingly", "scoffingly", "scoldedly", "scoldingly", "scorchingly", "scornedly", "scornfully", "scowlingly", "scratchily", "scrumptiously", "scrupulously", "scurrilously", "seamlessly", "searchingly", "searingly", "secondarily", "secretively", "secretly", "sectionally", "securely", "sedately", "seditiously", "seductively", "sedulously", "seekingly", "seemingly", "seethingly", "seldom", "selectively", "selfishly", "selflessly", "semantically", "sensationally", "senselessly", "sensibly", "sensitively", "sensually", "sensuously", "sententiously", "sentimentally", "separately", "sepulchrally", "sequentially", "serendipitously", "serenely", "seriously", "serpentinely", "serviceably", "servilely", "severely", "sexily", "shabbily", "shaggily", "shakenly", "shakily", "shakingly", "shallowly", "shamefacedly", "shamefully", "shamelessly", "shapelessly", "sharply", "shatteringly", "sheepishly", "shiftily", "shiftingly", "shimmeringly", "shinily", "shiningly", "shirkingly", "shiveringly", "shockedly", "shockingly", "shortly", "showily", "showingly", "shrewdly", "shrewishly", "shrilly", "shrinkingly", "shudderingly", "shyly", "sibilantly", "sickeningly", "sickly", "sidewardly", "sideways", "sighingly", "sightlessly", "significantly", "silently", "silkily", "sillily", "similarly", "simperingly", "simplistically", "simply", "simultaneously", "sincerely", "sinfully", "singingly", "singlehandedly", "singlemindedly", "singularly", "sinisterly", "sinuously", "skeptically", "sketchily", "skillfully", "skimpily", "skittishly", "skyward", "slackly", "slanderously", "slavishly", "sleekly", "sleepily", "slenderly", "slickly", "slightingly", "slightly", "slimily", "slipperily", "slippingly", "slobberingly", "sloppily", "slothfully", "slovenly", "slower", "slowly", "sluggishly", "slurringly", "sluttishly", "slyly", "smarmily", "smartly", "smilingly", "smirkingly", "smokily", "smolderingly", "smoothly", "smotheredly", "smotheringly", "smugly", "smuttily", "snappily", "sneakily", "sneeringly", "snidely", "sniffily", "snippily", "snobbily", "snobbishly", "snootily", "snowily", "snuffingly", "snugly", "soaked", "soapily", "sobbingly", "soberly", "sobersidedly", "sociably", "soddenly", "softer", "softheartedly", "softly", "soggily", "solely", "solemnly", "solicitously", "solidly", "solitarily", "somberly", "somehow", "sometimes", "somewhat", "somnolently", "sonorously", "soon", "soothedly", "soothingly", "sophisticatedly", "soporifically", "soppily", "soppingly", "sordidly", "sorely", "sororially", "sorrowfully", "sottily", "soulfully", "soundlessly", "soundly", "sourly", "southeastwardly", "southward", "southwardly", "southwestwardly", "spaciously", "sparingly", "sparkily", "sparklingly", "sparsely", "spartanly", "spasmodically", "spastically", "spatially", "specially", "specifically", "speciously", "speculatively", "speechlessly", "speedily", "spellbindingly", "spicily", "spikily", "spinelessly", "spiritedly", "spiritlessly", "spiritually", "spitefully", "splendidly", "splenetically", "spoiledly", "spontaneously", "spookily", "sporadically", "sportively", "spotlessly", "spottily", "spritely", "sprucely", "spryly", "spunkily", "squarely", "squeakily", "squeamishly", "squelchily", "stably", "staidly", "stalely", "stalwartly", "stammeringly", "standoffishly", "starchily", "starkly", "startledly", "startlingly", "stately", "statuesquely", "staunchly", "steadfastly", "steadily", "steadyingly", "stealthily", "steamily", "steelily", "steeply", "sternly", "stickily", "stiffledly", "stiffly", "stifledly", "still", "stiltedly", "stimulatingly", "stingily", "stingingly", "stintingly", "stodgily", "stoically", "stolidly", "stonily", "stormily", "stoutly", "straight", "straightfacedly", "straightforwardly", "straightly", "strainedly", "strangely", "strangledly", "strategically", "strenuously", "stressedly", "stressfully", "strictly", "stridently", "strikingly", "stringently", "strongly", "structurally", "stubbornly", "studiously", "stuffily", "stumblingly", "stunnedly", "stunningly", "stupefiedly", "stupendously", "stupidly", "stupified", "stuporously", "sturdily", "stutteringly", "stylishly", "suavely", "subconsciously", "subduedly", "subjectively", "subliminally", "submissively", "subsequently", "subserviently", "substantially", "subtly", "subversively", "successfully", "successively", "succinctly", "succulently", "suddenly", "sufferingly", "sufficiently", "suffocatingly", "suggestingly", "suggestively", "suitably", "sulkily", "sullenly", "sultrily", "summarily", "sumptuously", "sunnily", "superbly", "superciliously", "superficially", "superfluously", "superiorily", "superstitiously", "supplely", "suppliantly", "supplicatingly", "supportedly", "supportively", "supposedly", "suppressedly", "surefootedly", "surely", "surlily", "surprisedly", "surprisingly", "surreally", "surrenderingly", "surreptitiously", "suspectingly", "suspensefully", "suspiciously", "susurringly", "sveltely", "swaggeringly", "sweatily", "sweepingly", "sweetly", "swiftly", "swinishly", "swishingly", "swollenly", "sycophantically", "symbolically", "symmetrically", "sympathetically", "systematically", "tacitly", "taciturnly", "tactfully", "tactically", "tactilely", "tactlessly", "tactually", "talentedly", "talkatively", "tamely", "tangentially", "tantalisingly", "tantalizingly", "tardily", "tartly", "tastefully", "tastelessly", "tastily", "tauntingly", "tautly", "tawdrily", "tearfully", "tearily", "tearingly", "teasingly", "tediously", "tellingly", "temerariously", "temperamentally", "temperately", "tempestuously", "temporarily", "temptedly", "temptingly", "tenaciously", "tenderly", "tensely", "tentatively", "tenuously", "tepidly", "terribly", "terrifiedly", "terrifyingly", "territorially", "tersely", "testily", "testingly", "tetchily", "thankfully", "thanklessly", "theatrically", "then", "theoretically", "therapeutically", "thickheadedly", "thickly", "thinly", "thirstily", "thornily", "thoroughly", "thoughtfully", "thoughtlessly", "threatenedly", "threateningly", "thrice", "thriftily", "thrillingly", "throatily", "throbbingly", "thuggishly", "thumpingly", "thunderingly", "thunderously", "thusly", "thwartedly", "ticklishly", "tidily", "tighter", "tightly", "timidly", "timorously", "tinglingly", "tinklingly", "tippily", "tipsily", "tiredly", "tirelessly", "tiresomely", "tiringly", "together", "tolerably", "tolerantly", "tomboyishly", "tomorrow", "tonelessly", "too", "toothily", "toothlessly", "topically", "tormentedly", "tormentingly", "tornly", "torpidly", "torridly", "torturously", "totally", "touchedly", "touchily", "touchingly", "toughly", "tousledly", "toweringly", "toxically", "traditionally", "tragically", "trailingly", "traitorously", "tranquilly", "transfixedly", "translucently", "transparently", "transportedly", "trappedly", "traumatically", "treacherously", "treasonably", "treasonously", "tremblingly", "tremendously", "tremulously", "trenchantly", "trepidly", "triangularly", "trickily", "trillingly", "trimly", "tritely", "triumphantly", "troubledly", "truculently", "truly", "trustingly", "trustworthily", "truthfully", "tumidly", "tumultuously", "tunefully", "tunelessly", "turbulently", "turgidly", "twangily", "twice", "twinklingly", "twistedly", "twitchily", "twitchingly", "typically", "tyrannically", "ultimately", "unabashedly", "unaccountably", "unaccustomedly", "unaffectedly", "unaggressively", "unambitiously", "unamiably", "unamicably", "unamusedly", "unannounced", "unapologetically", "unappetizingly", "unappreciatively", "unashamedly", "unassumingly", "unathletically", "unattractively", "unavoidably", "unawares", "unbearably", "unbecomingly", "unbelievingly", "unbelligerently", "unbendingly", "unbiasedly", "unblinkingly", "unblushingly", "uncannily", "uncaringly", "unceremoniously", "uncertainly", "unchangingly", "uncharacteristically", "uncharitably", "unchastely", "uncheerfully", "unchivalrously", "uncivilly", "unclearly", "uncleverly", "uncomfortably", "uncommunicatively", "uncompetitively", "uncomplainingly", "uncompliantly", "uncomplicatedly", "uncomprehendingly", "uncompromisingly", "unconcernedly", "unconditionally", "uncongenially", "unconsciously", "unconsolably", "uncontrollably", "unconvincedly", "unconvincingly", "uncooperatively", "uncoordinatedly", "uncordially", "uncourageously", "uncouthly", "uncritically", "unctuously", "unctuousnessly", "undauntedly", "undecidedly", "undecipherably", "undefeatedly", "undeniably", "underfoot", "underhandedly", "understandably", "understandingly", "understatedly", "undeservingly", "undignifiedly", "undistractedly", "undividedly", "undoubtedly", "undulatingly", "uneasily", "unemotionally", "unendingly", "unenlightenedly", "unenthusiastically", "unenviously", "unequally", "unequivocally", "unerringly", "unethically", "unevenly", "unexpectedly", "unfairly", "unfaithfully", "unfalteringly", "unfamiliarly", "unfashionably", "unfavorably", "unfavourably", "unfazedly", "unfearingly", "unfeelingly", "unfemininely", "unflappably", "unflickeringly", "unflinchingly", "unfocusedly", "unforgetfully", "unforgivingly", "unfortunately", "ungainly", "ungallantly", "ungenerously", "ungenially", "unglamourously", "ungraciously", "ungratefully", "ungrudgingly", "unguardedly", "unguiltily", "unhaltingly", "unhappily", "unharmoniously", "unhealthily", "unheedingly", "unhelpfully", "unheroically", "unhesitantly", "unhesitatingly", "unhurriedly", "uniformly", "unimaginatively", "unimpeachably", "unimportantly", "unimposingly", "unimpressedly", "unimpressively", "unindulgently", "uninformatively", "uninhibitedly", "uninquisitively", "uninspiredly", "unintelligently", "unintelligibly", "unintentionally", "uninterestedly", "uninterruptedly", "uninvitedly", "uninvitingly", "uniquely", "unitedly", "universally", "unkindly", "unknowingly", "unmelodiously", "unmercifully", "unmindfully", "unmotivatedly", "unmovingly", "unmusically", "unnaturally", "unnecessarily", "unnervedly", "unnervingly", "unnoticeably", "unobservantly", "unobservedly", "unobtrusively", "unofficially", "unorthodoxly", "unostentatiously", "unperturbedly", "unpleasantly", "unpoetically", "unprecedentedly", "unpredictably", "unpreparedly", "unpretentiously", "unproductively", "unprofessionally", "unproficiently", "unpropitiously", "unprotectedly", "unquestioningly", "unrealistically", "unreasonably", "unreceptively", "unrefinedly", "unregretfully", "unrelatedly", "unrelentingly", "unreluctantly", "unremorsefully", "unrepentantly", "unrequitedly", "unreservedly", "unresponsively", "unrestrainedly", "unrevealingly", "unrhythmically", "unromantically", "unruffledly", "unsatisfactorily", "unsatisfiedly", "unscrupulously", "unseasonably", "unseeingly", "unseen", "unselfconsciously", "unselfishly", "unsettledly", "unsettlingly", "unshakably", "unskillfully", "unsmilingly", "unsociably", "unsolicitously", "unsparingly", "unspeakingly", "unsteadily", "unstintingly", "unsubmissively", "unsubtly", "unsuccessfully", "unsurely", "unsurprisedly", "unsurprisingly", "unsuspectingly", "unswervingly", "unsymmetrically", "unsympathetically", "unsystematically", "unthinkingly", "unthreateningly", "untruly", "untrustingly", "untruthfully", "unusually", "unvirtuously", "unwantedly", "unwarily", "unwaveringly", "unwelcomingly", "unwillingly", "unwisely", "unwittingly", "unyieldingly", "upbeat", "upliftingly", "upright", "uprightly", "uproariously", "upsetly", "upward", "upwardly", "urbanely", "urgently", "usefully", "uselessly", "usually", "utterly", "uxoriously", "vacantly", "vacillatorily", "vacuously", "vaguely", "vaingloriously", "vainly", "valiantly", "validly", "valorously", "vapidly", "vastly", "vauntingly", "vehemently", "venally", "venerably", "veneratively", "vengefully", "venomously", "venturesomely", "veraciously", "verbally", "verbatim", "verbosely", "veritably", "vertically", "very", "vexedly", "vibrantly", "vibratingly", "vicariously", "viciously", "victoriously", "vigilantly", "vigorously", "vilely", "villainously", "vindicatedly", "vindictively", "violently", "virginally", "virtuously", "virulently", "viscously", "visibly", "visually", "vituperatively", "vivaciously", "vividly", "vocally", "vociferously", "voicelessly", "volatilely", "voluminously", "voluntarily", "voluptuously", "voraciously", "voyeuristically", "vulgarly", "vulnerably", "vyingly", "waggishly", "waifishly", "wakefully", "wanderingly", "wanly", "wantingly", "wantonly", "warily", "warmly", "warningly", "waspishly", "watchfully", "waveringly", "waywardly", "weakly", "wearily", "wearisomely", "weepily", "weightily", "weirdly", "welcomingly", "well", "westward", "westwardly", "wetly", "wheedlingly", "wheezingly", "whimperingly", "whimsically", "whinily", "whiningly", "whisperingly", "wholeheartedly", "wholly", "wickedly", "widely", "wildly", "wilfully", "wilily", "willfully", "willingly", "wimpily", "wimpishly", "wincingly", "windedly", "winningly", "winsomely", "wintrily", "wisely", "wishfully", "wispily", "wistfully", "withdrawn", "witheringly", "witlessly", "wittily", "wittingly", "wobbily", "woefully", "wolfishly", "wonderfully", "wonderingly", "wondrously", "woodenly", "woozily", "wordily", "wordlessly", "workably", "worriedly", "worrisome", "worshipfully", "worshippingly", "worthily", "worthlessly", "woundedly", "wrathfully", "wrenchingly", "wretchedly", "wrinkledly", "wrongly", "wryly", "yawningly", "yearly", "yearningly", "yesterday", "yieldingly", "youthfully", "zealously", "zestfully", "zestily"]
adjectives = ["abandoned", "able", "absolute", "academic", "acceptable", "acclaimed", "accomplished", "accurate", "aching", "acidic", "acrobatic", "active", "actual", "adept", "admirable", "admired", "admiring", "adolescent", "adorable", "adored", "adoring", "advanced", "adventurous", "affectionate", "afraid", "aged", "aggravating", "aggressive", "agile", "agitated", "agonizing", "agreeable", "ajar", "alarmed", "alarming", "alert", "alienated", "alive", "all", "altruistic", "amazing", "ambitious", "ample", "amused", "amusing", "anchored", "ancient", "angelic", "angry", "anguished", "animated", "annual", "another", "antique", "anxious", "any", "apprehensive", "appropriate", "apt", "arctic", "arid", "aromatic", "artistic", "ashamed", "assured", "astonishing", "athletic", "attached", "attentive", "attractive", "austere", "authentic", "authorized", "automatic", "avaricious", "average", "aware", "awesome", "awful", "awkward", "babyish", "back", "backstabbing", "bad", "baggy", "bare", "barren", "basic", "beautiful", "belated", "beloved", "beneficial", "berserk", "best", "better", "bewitched", "big", "biodegradable", "bitesize", "bitter", "black", "bland", "blank", "blaring", "bleak", "blind", "blissful", "blond", "blue", "blushing", "bogus", "boiling", "bold", "bony", "boring", "bossy", "both", "bouncy", "bountiful", "bowed", "brave", "breakable", "brief", "bright", "brilliant", "brisk", "broken", "bronze", "brown", "bruised", "bubbly", "bulky", "bumpy", "buoyant", "burdensome", "burly", "bustling", "busy", "buttery", "buzzing", "calculating", "calm", "candid", "canine", "capital", "carefree", "careful", "careless", "caring", "cautious", "cavernous", "celebrated", "charming", "cheap", "cheerful", "cheery", "chief", "chilly", "chubby", "circular", "classic", "clean", "clear", "clever", "close", "closed", "cloudy", "clueless", "clumsy", "cluttered", "coarse", "cocky", "cold", "colorful", "colorless", "colossal", "comfortable", "common", "compassionate", "competent", "complete", "complex", "complicated", "composed", "concerned", "concrete", "condescending", "confused", "conscious", "considerate", "constant", "content", "conventional", "cooked", "cool", "cooperative", "coordinated", "corny", "corrupt", "costly", "courageous", "courteous", "crafty", "cranky", "crazy", "creamy", "creative", "creepy", "criminal", "crisp", "critical", "crooked", "crowded", "cruel", "crushing", "cuddly", "cultivated", "cultured", "cumbersome", "curly", "curvy", "cute", "cylindrical", "damaged", "damp", "dangerous", "dapper", "daring", "dark", "darling", "dazzling", "dead", "deadly", "deafening", "dear", "dearest", "decent", "decimal", "decisive", "deep", "defenseless", "defensive", "defiant", "deficient", "definite", "definitive", "delayed", "delectable", "delicious", "delightful", "delirious", "demanding", "dense", "dental", "dependable", "dependent", "descriptive", "deserted", "desperate", "detailed", "determined", "devoted", "different", "difficult", "digital", "diligent", "dim", "dimpled", "dimwitted", "direct", "dirty", "disastrous", "discrete", "disfigured", "disguised", "disgusting", "dishonest", "disloyal", "dismal", "distant", "distinct", "distorted", "distracted", "dizzy", "dopey", "doting", "double", "downright", "drab", "drafty", "dramatic", "dreamy", "dreary", "droopy", "drunk", "dry", "dual", "dull", "dutiful", "each", "eager", "early", "earnest", "easy", "easygoing", "ecstatic", "edible", "educated", "elaborate", "elastic", "elated", "elderly", "electric", "elegant", "elementary", "elliptical", "embarrassed", "embellished", "eminent", "emotional", "empty", "enchanted", "enchanting", "energetic", "enlightened", "enormous", "enraged", "entire", "envious", "equal", "equatorial", "essential", "esteemed", "ethical", "euphoric", "even", "evergreen", "everlasting", "every", "evil", "exalted", "excellent", "excitable", "excited", "exciting", "exemplary", "exhausted", "exotic", "expensive", "experienced", "expert", "extraneous", "extroverted", "fabulous", "failing", "faint", "fair", "faithful", "fake", "false", "familiar", "famous", "fancy", "fantastic", "far", "faraway", "fast", "fat", "fatal", "fatherly", "favorable", "favorite", "fearful", "fearless", "feisty", "feline", "female", "feminine", "fervent", "few", "fickle", "filthy", "fine", "finished", "firm", "first", "firsthand", "fitting", "fixed", "flaky", "flamboyant", "flashy", "flat", "flawed", "flawless", "flickering", "flimsy", "flippant", "flowery", "fluffy", "fluid", "flustered", "focused", "fond", "foolhardy", "foolish", "forceful", "forked", "formal", "forsaken", "forthright", "fortunate", "fragrant", "frail", "frank", "frayed", "free", "french", "frequent", "fresh", "friendly", "frightened", "frightening", "frigid", "frilly", "frivolous", "frizzy", "front", "frosty", "frozen", "frugal", "fruitful", "full", "fumbling", "functional", "funny", "furious", "fussy", "fuzzy", "gargantuan", "gaseous", "general", "generous", "gentle", "genuine", "giant", "giddy", "gifted", "gigantic", "giving", "glamorous", "glaring", "glass", "gleaming", "gleeful", "glistening", "glittering", "gloomy", "glorious", "glossy", "glum", "golden", "good", "goofy", "gorgeous", "graceful", "gracious", "grand", "grandiose", "granular", "grateful", "grave", "gray", "great", "greedy", "green", "gregarious", "grim", "grimy", "gripping", "grizzled", "gross", "grotesque", "grouchy", "grounded", "growing", "growling", "grown", "grubby", "gruesome", "grumpy", "guilty", "gullible", "gummy", "hairy", "half", "handmade", "handsome", "handy", "happy", "hard", "harmful", "harmless", "harmonious", "harsh", "hasty", "hateful", "haunting", "healthy", "heartfelt", "hearty", "heavenly", "heavy", "hefty", "helpful", "helpless", "hidden", "hideous", "high", "hilarious", "hoarse", "hollow", "homely", "honest", "honorable", "honored", "hopeful", "horrible", "hospitable", "hot", "huge", "humble", "humiliating", "humming", "humongous", "hungry", "hurtful", "husky", "icky", "icy", "ideal", "idealistic", "identical", "idiotic", "idle", "idolized", "ignorant", "ill", "illegal", "illiterate", "illustrious", "imaginary", "imaginative", "immaculate", "immaterial", "immediate", "immense", "impartial", "impassioned", "impeccable", "imperfect", "imperturbable", "impish", "impolite", "important", "impossible", "impractical", "impressionable", "impressive", "improbable", "impure", "inborn", "incomparable", "incompatible", "incomplete", "inconsequential", "incredible", "indelible", "indolent", "inexperienced", "infamous", "infantile", "infatuated", "inferior", "infinite", "informal", "innocent", "insane", "insecure", "insidious", "insignificant", "insistent", "instructive", "insubstantial", "intelligent", "intent", "intentional", "interesting", "internal", "international", "intrepid", "ironclad", "irresponsible", "irritating", "itchy", "jaded", "jagged", "jaunty", "jealous", "jittery", "joint", "jolly", "jovial", "joyful", "joyous", "jubilant", "judicious", "juicy", "jumbo", "jumpy", "junior", "juvenile", "kaleidoscopic", "keen", "key", "kickass", "kind", "kindhearted", "kindly", "klutzy", "knobby", "knotty", "knowing", "knowledgeable", "known", "kooky", "kosher", "lame", "lanky", "large", "last", "lasting", "late", "lavish", "lawful", "lazy", "leading", "leafy", "lean", "left", "legal", "legitimate", "light", "lighthearted", "likable", "likely", "limited", "limp", "limping", "linear", "lined", "liquid", "little", "live", "lively", "livid", "loathsome", "lone", "lonely", "long", "loose", "lopsided", "lost", "loud", "lovable", "lovely", "loving", "low", "loyal", "lucky", "lumbering", "luminous", "lumpy", "lustrous", "luxurious", "mad", "magnificent", "majestic", "major", "male", "mammoth", "married", "marvelous", "masculine", "massive", "mature", "meager", "mealy", "mean", "measly", "meaty", "medical", "mediocre", "medium", "meek", "mellow", "melodic", "memorable", "menacing", "merry", "messy", "metallic", "mild", "milky", "mindless", "miniature", "minor", "minty", "miserable", "miserly", "misguided", "misty", "mixed", "modern", "modest", "moist", "monstrous", "monthly", "monumental", "moral", "mortified", "motherly", "motionless", "mountainous", "muddy", "muffled", "multicolored", "mundane", "murky", "mushy", "musty", "muted", "mysterious", "naive", "narrow", "nasty", "natural", "naughty", "nautical", "near", "neat", "necessary", "needy", "negative", "neglected", "negligible", "neighboring", "nervous", "new", "next", "nice", "nifty", "nimble", "nippy", "nocturnal", "noisy", "nonstop", "normal", "nostalgic", "notable", "noted", "noteworthy", "novel", "noxious", "numb", "nutritious", "nutty", "obedient", "obese", "oblong", "obvious", "occasional", "odd", "oddball", "offbeat", "offensive", "official", "oily", "old", "onerlooked", "only", "open", "optimal", "optimistic", "opulent", "orange", "orderly", "ordinary", "organic", "original", "ornate", "ornery", "other", "our", "outgoing", "outlandish", "outlying", "outrageous", "outstanding", "oval", "overcooked", "overdue", "overjoyed", "palatable", "pale", "paltry", "parallel", "parched", "partial", "passionate", "past", "pastel", "peaceful", "pensive", "peppery", "perfect", "perfumed", "periodic", "perky", "personal", "pertinent", "pesky", "pessimistic", "petty", "phony", "physical", "piercing", "pink", "pitiful", "plain", "plaintive", "plastic", "playful", "pleasant", "pleased", "pleasing", "plump", "plush", "pointed", "pointless", "poised", "polished", "polite", "political", "poor", "popular", "portly", "posh", "positive", "possible", "potable", "powerful", "powerless", "practical", "precious", "present", "prestigious", "pretty", "previous", "pricey", "prickly", "primary", "prime", "pristine", "private", "prize", "probable", "productive", "profitable", "profuse", "proper", "proud", "prudent", "punctual", "pungent", "puny", "pure", "purple", "pushy", "putrid", "puzzled", "puzzling", "quaint", "qualified", "quarrelsome", "quarterly", "queasy", "querulous", "questionable", "quick", "quiet", "quintessential", "quirky", "quixotic", "quizzical", "radiant", "ragged", "rapid", "rare", "rash", "raw", "ready", "real", "realistic", "reasonable", "recent", "reckless", "rectangular", "red", "reflecting", "regal", "regular", "reliable", "relieved", "remarkable", "remorseful", "remote", "repentant", "repulsive", "required", "respectful", "responsible", "reverent", "revolving", "rewarding", "rich", "right", "rigid", "ringed", "ripe", "roasted", "robust", "romantic", "rosy", "rotating", "rotten", "rough", "round", "rowdy", "royal", "rubbery", "ruddy", "rude", "rundown", "runny", "rural", "rusty", "sad", "safe", "salty", "same", "sandy", "sane", "sarcastic", "sardonic", "satisfied", "scaly", "scarce", "scared", "scary", "scented", "scholarly", "scientific", "scornful", "scratchy", "scrawny", "second", "secondary", "secret", "selfish", "sentimental", "separate", "serene", "serious", "serpentine", "several", "severe", "shabby", "shadowy", "shady", "shallow", "shameful", "shameless", "sharp", "shimmering", "shiny", "shocked", "shocking", "shoddy", "short", "showy", "shrill", "shy", "sick", "silent", "silky", "silly", "silver", "similar", "simple", "simplistic", "sinful", "single", "sizzling", "skeletal", "skinny", "sleepy", "slight", "slim", "slimy", "slippery", "slow", "slushy", "small", "smart", "smoggy", "smooth", "smug", "snappy", "snarling", "sneaky", "sniveling", "snoopy", "sociable", "soft", "soggy", "solid", "somber", "some", "sophisticated", "sore", "sorrowful", "soulful", "soupy", "sour", "spanish", "sparkling", "sparse", "specific", "spectacular", "speedy", "spherical", "spicy", "spiffy", "spirited", "spiteful", "splendid", "spotless", "spotted", "spry", "square", "squeaky", "squiggly", "stable", "staid", "stained", "stale", "standard", "starchy", "stark", "starry", "steel", "steep", "sticky", "stiff", "stimulating", "stingy", "stoic", "stormy", "straight", "strange", "strict", "strident", "striking", "striped", "strong", "studious", "stunning", "stupefied", "stupendous", "stupid", "sturdy", "stylish", "subdued", "submissive", "substantial", "subtle", "suburban", "sudden", "sugary", "sunny", "super", "superb", "superficial", "superior", "supportive", "surprised", "suspicious", "svelte", "sweaty", "sweet", "sweltering", "swift", "sympathetic", "talkative", "tall", "tame", "tan", "tangible", "tart", "tasty", "tattered", "taut", "tedious", "teeming", "tempting", "tender", "tense", "tepid", "terrible", "terrific", "testy", "thankful", "that", "these", "thick", "thin", "third", "thirsty", "this", "thorny", "thorough", "those", "thoughtful", "threadbare", "thrifty", "thunderous", "tidy", "tight", "timely", "tinted", "tiny", "tired", "torn", "total", "tough", "tragic", "trained", "traumatic", "treasured", "tremendous", "triangular", "tricky", "trifling", "trim", "trivial", "troubled", "true", "trusting", "trustworthy", "trusty", "truthful", "tubby", "turbulent", "twin", "ugly", "ultimate", "unacceptable", "unaware", "uncomfortable", "uncommon", "unconscious", "understated", "unequaled", "uneven", "unfinished", "unfit", "unfolded", "unfortunate", "unhappy", "unhealthy", "uniform", "unimportant", "unique", "united", "unkempt", "unknown", "unlawful", "unlined", "unlucky", "unnatural", "unpleasant", "unrealistic", "unripe", "unruly", "unselfish", "unsightly", "unsteady", "unsung", "untidy", "untimely", "untried", "untrue", "unused", "unusual", "unwelcome", "unwieldy", "unwilling", "unwitting", "unwritten", "upbeat", "upright", "upset", "urban", "usable", "used", "useful", "useless", "utilized", "utter", "vacant", "vague", "vain", "valid", "valuable", "vapid", "variable", "vast", "velvety", "venerated", "vengeful", "verifiable", "vibrant", "vicious", "victorious", "vigilant", "vigorous", "villainous", "violent", "violet", "virtual", "virtuous", "visible", "vital", "vivacious", "vivid", "voluminous", "wan", "warlike", "warm", "warmhearted", "warped", "wary", "wasteful", "watchful", "waterlogged", "watery", "wavy", "weak", "wealthy", "weary", "webbed", "wee", "weekly", "weepy", "weighty", "weird", "welcome", "wet", "which", "whimsical", "whirlwind", "whispered", "white", "whole", "whopping", "wicked", "wide", "wiggly", "wild", "willing", "wilted", "winding", "windy", "winged", "wiry", "wise", "witty", "wobbly", "woeful", "wonderful", "wooden", "woozy", "wordy", "worldly", "worn", "worried", "worrisome", "worse", "worst", "worthless", "worthwhile", "worthy", "wrathful", "wretched", "writhing", "wrong", "wry", "yawning", "yearly", "yellow", "yellowish", "young", "youthful", "yummy", "zany", "zealous", "zesty", "zigzag"]
names = ["Aaden", "Aaliyah", "Aarav", "Aaron", "Abbigail", "Abby", "Abdiel", "Abdullah", "Abel", "Abigail", "Abraham", "Abram", "Abrielle", "Abril", "Ace", "Ada", "Adalyn", "Adalynn", "Adam", "Adan", "Addilyn", "Addison", "Addisyn", "Addyson", "Adelaide", "Adele", "Adelina", "Adeline", "Adelyn", "Adelynn", "Aden", "Aditya", "Adonis", "Adrian", "Adriana", "Adrianna", "Adriel", "Adrien", "Adrienne", "Ahmad", "Ahmed", "Aidan", "Aiden", "Aidyn", "Aileen", "Aimee", "Ainsley", "Aisha", "Aiyana", "Alaina", "Alan", "Alana", "Alani", "Alanna", "Alannah", "Alaya", "Alayah", "Alayna", "Alaysia", "Albert", "Alberto", "Alden", "Aldo", "Aleah", "Alec", "Aleena", "Aleigha", "Alejandra", "Alejandro", "Alena", "Alessandra", "Alessandro", "Alex", "Alexa", "Alexander", "Alexandra", "Alexandria", "Alexia", "Alexis", "Alexzander", "Alfonso", "Alfred", "Alfredo", "Ali", "Alia", "Aliana", "Alice", "Alicia", "Alijah", "Alina", "Alisha", "Alison", "Alissa", "Alisson", "Alivia", "Aliya", "Aliyah", "Aliza", "Allan", "Allen", "Allie", "Allison", "Ally", "Allyson", "Alma", "Alondra", "Alonso", "Alonzo", "Alvaro", "Alvin", "Alyson", "Alyssa", "Alyvia", "Amalia", "Amanda", "Amani", "Amara", "Amare", "Amari", "Amaya", "Amber", "Ambroise", "Ameer", "Amelia", "Amelie", "America", "Amia", "Amina", "Amir", "Amira", "Amirah", "Amiya", "Amiyah", "Amos", "Amy", "Amya", "Ana", "Anabel", "Anabella", "Anabelle", "Anahi", "Anastasia", "Anaya", "Anders", "Anderson", "Andre", "Andrea", "Andres", "Andrew", "Andy", "Angel", "Angela", "Angelica", "Angelina", "Angeline", "Angelique", "Angelo", "Angie", "Anika", "Aniya", "Aniyah", "Ann", "Anna", "Annabel", "Annabell", "Annabella", "Annabelle", "Annalee", "Annalise", "Anne", "Annie", "Annika", "Ansley", "Anson", "Anthony", "Antoine", "Antonio", "Anya", "Apollo", "April", "Arabella", "Araceli", "Archer", "Archimedes", "Arely", "Ares", "Ari", "Aria", "Ariah", "Arian", "Ariana", "Arianna", "Ariel", "Ariella", "Arielle", "Ariya", "Ariyah", "Arjun", "Arlo", "Armando", "Armani", "Arnav", "Aron", "Arthur", "Arturo", "Arya", "Aryan", "Aryana", "Aryanna", "Asa", "Asher", "Ashley", "Ashlyn", "Ashlynn", "Ashton", "Asia", "Aspen", "Astrid", "Athena", "Atlas", "Atticus", "Aubree", "Aubrey", "Aubri", "Aubrianna", "Aubrie", "Aubrielle", "Audrey", "Audriana", "Audrianna", "Audrina", "August", "Augustine", "Augustus", "Aurelia", "Aurora", "Austin", "Autumn", "Ava", "Avah", "Avalyn", "Averi", "Averie", "Avery", "Aviana", "Avianna", "Axel", "Axton", "Ayaan", "Ayana", "Ayanna", "Aydan", "Ayden", "Aydin", "Ayla", "Ayleen", "Aylin", "Azalea", "Azaria", "Azariah", "Bailee", "Bailey", "Barbara", "Barrett", "Baylee", "Bayleigh", "Beatrice", "Beau", "Beckett", "Beckham", "Belen", "Belinda", "Bella", "Ben", "Benjamin", "Bennett", "Benson", "Bentlee", "Bentley", "Bently", "Benton", "Bethany", "Bianca", "Billy", "Blaine", "Blair", "Blaise", "Blake", "Blakely", "Blaze", "Bo", "Bobby", "Bodhi", "Boston", "Bowen", "Braden", "Bradley", "Brady", "Braeden", "Braelyn", "Braelynn", "Braiden", "Branden", "Brandon", "Branson", "Brantlee", "Brantley", "Braxton", "Brayan", "Brayden", "Braydon", "Braylee", "Braylen", "Braylon", "Breanna", "Brecken", "Brenda", "Brendan", "Brenden", "Brendon", "Brenna", "Brennan", "Brent", "Brentley", "Brenton", "Brett", "Bria", "Brian", "Briana", "Brianna", "Brice", "Bridger", "Bridget", "Briella", "Brielle", "Briggs", "Briley", "Brinley", "Bristol", "Britney", "Brittany", "Brock", "Broderick", "Brodie", "Brody", "Bronson", "Brooke", "Brooklyn", "Brooklynn", "Brooks", "Bruce", "Bruno", "Bryan", "Bryanna", "Bryant", "Bryce", "Brycen", "Brylee", "Bryleigh", "Bryn", "Brynlee", "Brynn", "Brysen", "Bryson", "Byron", "Cade", "Caden", "Cadence", "Caiden", "Cain", "Caitlin", "Caitlyn", "Caleb", "Cali", "Callan", "Callen", "Callie", "Callum", "Calvin", "Camden", "Camdyn", "Cameron", "Camila", "Camilla", "Camille", "Camilo", "Campbell", "Camren", "Camron", "Camryn", "Cannon", "Cara", "Carl", "Carla", "Carlee", "Carley", "Carlie", "Carlos", "Carly", "Carmelo", "Carmen", "Carolina", "Caroline", "Carolyn", "Carson", "Carter", "Case", "Casen", "Casey", "Cash", "Cason", "Cassandra", "Cassidy", "Cassius", "Castiel", "Cataleya", "Catalina", "Catherine", "Cayden", "Caylee", "Cayson", "Cecelia", "Cecilia", "Cedric", "Celeste", "Celia", "Celine", "Cesar", "Chace", "Chad", "Chaim", "Chana", "Chance", "Chandler", "Chanel", "Channing", "Charity", "Charlee", "Charleigh", "Charles", "Charley", "Charli", "Charlie", "Charlize", "Charlotte", "Chase", "Chaya", "Chelsea", "Cherish", "Cheyenne", "Chloe", "Chris", "Christian", "Christina", "Christine", "Christopher", "Ciara", "Cindy", "Claire", "Clara", "Clare", "Clarissa", "Clark", "Claudia", "Clay", "Clayton", "Clinton", "Clyde", "Cody", "Cohen", "Colby", "Cole", "Coleman", "Colette", "Colin", "Collin", "Collins", "Colt", "Colten", "Colton", "Conner", "Connor", "Conor", "Conrad", "Cooper", "Cora", "Coraline", "Corban", "Corbin", "Corey", "Corinne", "Cortez", "Cory", "Courtney", "Craig", "Crew", "Cristian", "Cristiano", "Cristina", "Cristopher", "Crosby", "Cruz", "Crystal", "Cullen", "Curtis", "Cynthia", "Cyrus", "Dahlia", "Daisy", "Dakota", "Daleyza", "Dalilah", "Dallas", "Dalton", "Damian", "Damien", "Damion", "Damon", "Dana", "Dane", "Dangelo", "Danica", "Daniel", "Daniela", "Daniella", "Danielle", "Danika", "Danna", "Danny", "Dante", "Daphne", "Darian", "Darien", "Dario", "Darius", "Darrell", "Darren", "Darwin", "Davian", "David", "Davin", "Davion", "Davis", "Davon", "Dawson", "Dax", "Daxton", "Dayana", "Dayton", "Deacon", "Dean", "Deandre", "Deangelo", "Deanna", "Deborah", "Declan", "Deegan", "Delaney", "Delilah", "Demarcus", "Demetrius", "Demi", "Denise", "Dennis", "Denzel", "Deon", "Derek", "Derrick", "Deshawn", "Desiree", "Desmond", "Destinee", "Destiny", "Devin", "Devon", "Devyn", "Dexter", "Diamond", "Diana", "Diego", "Dilan", "Dillon", "Dixie", "Dominic", "Dominick", "Dominik", "Dominique", "Donald", "Donovan", "Dorian", "Dorothy", "Douglas", "Drake", "Draven", "Drew", "Duke", "Dulce", "Duncan", "Dustin", "Dwayne", "Dylan", "Ean", "Easton", "Eddie", "Eden", "Edgar", "Edison", "Edith", "Eduardo", "Edward", "Edwin", "Efrain", "Eileen", "Elaina", "Elaine", "Eleanor", "Elena", "Eli", "Elian", "Eliana", "Elianna", "Elias", "Elijah", "Elin", "Elisa", "Elisabeth", "Elise", "Elisha", "Eliza", "Elizabeth", "Ella", "Elle", "Ellen", "Elliana", "Ellie", "Elliot", "Elliott", "Ellis", "Ellison", "Eloise", "Elsa", "Elsie", "Elyse", "Emanuel", "Ember", "Emelia", "Emely", "Emerie", "Emerson", "Emersyn", "Emery", "Emilee", "Emilia", "Emiliano", "Emilie", "Emilio", "Emily", "Emma", "Emmalee", "Emmaline", "Emmalyn", "Emmalynn", "Emmanuel", "Emmett", "Emmitt", "Emmy", "Emory", "Enoch", "Enrico", "Enrique", "Enzo", "Ephraim", "Eric", "Erica", "Erick", "Erik", "Erika", "Erin", "Erna", "Ernest", "Ernesto", "Esme", "Esmeralda", "Esteban", "Estella", "Estelle", "Esther", "Estrella", "Ethan", "Euclid", "Eugene", "Eva", "Evalyn", "Evan", "Evangeline", "Eve", "Evelyn", "Evelynn", "Everett", "Everleigh", "Everly", "Evie", "Ezekiel", "Ezequiel", "Ezra", "Fabian", "Faith", "Farrah", "Fatima", "Felicity", "Felipe", "Felix", "Fernanda", "Fernando", "Finley", "Finn", "Finnegan", "Fiona", "Fisher", "Fletcher", "Flynn", "Forrest", "Foster", "Frances", "Francesca", "Francis", "Francisco", "Franco", "Frank", "Frankie", "Franklin", "Frederick", "Freya", "Gabriel", "Gabriela", "Gabriella", "Gabrielle", "Gael", "Gage", "Galilea", "Galileo", "Gannon", "Garrett", "Garrison", "Gary", "Gauge", "Gavin", "Gavyn", "Gemma", "Genesis", "Genevieve", "George", "Georgia", "Gerald", "Gerardo", "Gertrude", "Gerty", "Gia", "Giada", "Giana", "Giancarlo", "Gianna", "Gianni", "Giavanna", "Gibson", "Gideon", "Gilbert", "Gilberto", "Gino", "Giovani", "Giovanna", "Giovanni", "Giovanny", "Giselle", "Giuliana", "Gloria", "Grace", "Gracelyn", "Gracelynn", "Gracie", "Grady", "Graeme", "Graham", "Grant", "Grayson", "Gregory", "Greta", "Grey", "Greyson", "Griffin", "Guadalupe", "Guillermo", "Gunnar", "Gunner", "Gustavo", "Gwen", "Gwendolyn", "Gwyneth", "Hadassah", "Hadlee", "Hadley", "Hailee", "Hailey", "Haleigh", "Haley", "Halle", "Hallie", "Hamza", "Hana", "Hank", "Hanna", "Hannah", "Harlan", "Harlee", "Harley", "Harlow", "Harmony", "Harold", "Harper", "Harrison", "Harry", "Harvey", "Hassan", "Hattie", "Haven", "Hayden", "Hayes", "Haylee", "Hayley", "Hazel", "Heath", "Heather", "Heaven", "Hector", "Heidi", "Helen", "Helena", "Hendrix", "Henley", "Henry", "Hezekiah", "Holden", "Holly", "Hope", "Houston", "Hudson", "Hugh", "Hugo", "Hunter", "Hypatia", "Ian", "Ibrahim", "Iker", "Iliana", "Imani", "Immanuel", "India", "Ingrid", "Ireland", "Irene", "Iris", "Isaac", "Isabel", "Isabela", "Isabella", "Isabelle", "Isaiah", "Isaias", "Ishaan", "Isiah", "Isis", "Isla", "Ismael", "Israel", "Issac", "Itzel", "Ivan", "Ivanna", "Ivory", "Ivy", "Izabella", "Izaiah", "Izayah", "Jace", "Jack", "Jackson", "Jacob", "Jacoby", "Jacqueline", "Jada", "Jade", "Jaden", "Jadiel", "Jadon", "Jaelyn", "Jaelynn", "Jagger", "Jaida", "Jaiden", "Jaime", "Jair", "Jairo", "Jake", "Jakob", "Jakobe", "Jalen", "Jaliyah", "Jamal", "Jamar", "Jamari", "Jamarion", "James", "Jameson", "Jamie", "Jamir", "Jamison", "Janae", "Jane", "Janelle", "Janessa", "Janiya", "Janiyah", "Jared", "Jase", "Jasiah", "Jasmin", "Jasmine", "Jason", "Jasper", "Javier", "Javion", "Javon", "Jax", "Jaxen", "Jaxon", "Jaxson", "Jaxton", "Jay", "Jayce", "Jaycee", "Jayceon", "Jaycob", "Jayda", "Jayde", "Jayden", "Jaydon", "Jayla", "Jaylah", "Jaylee", "Jayleen", "Jaylen", "Jaylene", "Jaylin", "Jaylynn", "Jayse", "Jayson", "Jazlyn", "Jazlynn", "Jazmin", "Jazmine", "Jean", "Jedidiah", "Jefferson", "Jeffery", "Jeffrey", "Jemma", "Jenna", "Jennifer", "Jenny", "Jensen", "Jeremiah", "Jeremy", "Jericho", "Jermaine", "Jerome", "Jerry", "Jesse", "Jessica", "Jessie", "Jett", "Jewel", "Jillian", "Jimena", "Jimmy", "Joanna", "Joaquin", "Jocelyn", "Jocelynn", "Joe", "Joel", "Joey", "Johan", "Johanna", "John", "Johnathan", "Johnathon", "Johnny", "Jolene", "Jolie", "Jon", "Jonah", "Jonas", "Jonathan", "Jonathon", "Jordan", "Jorden", "Jordy", "Jordyn", "Jordynn", "Jorge", "Jose", "Joselyn", "Joseph", "Josephine", "Joshua", "Josiah", "Josie", "Joslyn", "Josue", "Journee", "Journey", "Jovani", "Jovanni", "Joy", "Joyce", "Joziah", "Juan", "Judah", "Jude", "Judith", "Juelz", "Julia", "Julian", "Juliana", "Julianna", "Julianne", "Julie", "Julien", "Juliet", "Juliette", "Julio", "Julissa", "Julius", "June", "Junior", "Juniper", "Jurnee", "Justice", "Justin", "Justus", "Kade", "Kaden", "Kadence", "Kaeden", "Kaelyn", "Kai", "Kaia", "Kaiden", "Kaidence", "Kailani", "Kailee", "Kailey", "Kailyn", "Kairi", "Kaitlyn", "Kaitlynn", "Kaiya", "Kale", "Kaleb", "Kaleigh", "Kalel", "Kali", "Kaliyah", "Kallie", "Kamari", "Kamden", "Kamdyn", "Kameron", "Kamila", "Kamron", "Kamryn", "Kane", "Kannon", "Kara", "Kareem", "Karen", "Karina", "Karis", "Karissa", "Karla", "Karlee", "Karlie", "Karly", "Karma", "Karson", "Karsyn", "Karter", "Kase", "Kasen", "Kash", "Kason", "Kassandra", "Kassidy", "Katalina", "Kate", "Katelyn", "Katelynn", "Katherine", "Kathleen", "Kathryn", "Katie", "Kaya", "Kayden", "Kaydence", "Kayla", "Kaylee", "Kayleigh", "Kaylen", "Kaylie", "Kaylin", "Kaylyn", "Kaylynn", "Kaysen", "Kayson", "Keagan", "Keaton", "Keegan", "Keenan", "Keira", "Keith", "Kellan", "Kellen", "Kelly", "Kelsey", "Kelvin", "Kendall", "Kendra", "Kendrick", "Kenia", "Kenley", "Kenna", "Kennedi", "Kennedy", "Kenneth", "Kenny", "Kensley", "Kenya", "Kenzie", "Kevin", "Keyla", "Khalil", "Khloe", "Kian", "Kiana", "Kiara", "Kiera", "Kieran", "Kiley", "Killian", "Kimber", "Kimberly", "Kimora", "King", "Kingsley", "Kingston", "Kinley", "Kinsley", "Kira", "Knox", "Kobe", "Kody", "Kohen", "Kolby", "Kole", "Kolten", "Kolton", "Konner", "Konnor", "Kora", "Korbin", "Kori", "Kourtney", "Krish", "Kristen", "Kristian", "Kristina", "Kristopher", "Krystal", "Kyla", "Kylah", "Kylan", "Kyle", "Kylee", "Kyleigh", "Kyler", "Kylie", "Kymani", "Kyndall", "Kynlee", "Kyra", "Kyree", "Kyrie", "Kyson", "Lacey", "Lachlan", "Laila", "Lailah", "Lainey", "Lamar", "Lana", "Lance", "Landen", "Landon", "Landry", "Landyn", "Lane", "Laney", "Langston", "Lara", "Larry", "Laura", "Laurel", "Lauren", "Lauryn", "Lawrence", "Lawson", "Layla", "Laylah", "Layne", "Layton", "Lea", "Leah", "Leandro", "Leanna", "Lee", "Legend", "Leia", "Leighton", "Leila", "Leilani", "Leland", "Lena", "Lennon", "Lennox", "Leo", "Leon", "Leona", "Leonard", "Leonardo", "Leonel", "Leonidas", "Leroy", "Leslie", "Lesly", "Levi", "Lewis", "Lexi", "Lexie", "Leyla", "Lia", "Liam", "Liana", "Libby", "Liberty", "Lila", "Lilah", "Lilia", "Lilian", "Liliana", "Lilianna", "Lilith", "Lillian", "Lilliana", "Lillianna", "Lillie", "Lilly", "Lillyana", "Lily", "Lilyana", "Lilyanna", "Lina", "Lincoln", "Linda", "Lindsay", "Lindsey", "Linus", "Lionel", "Lisa", "Lise", "Liv", "Livia", "Lizbeth", "Lochlan", "Logan", "Lola", "London", "Londyn", "Lorelai", "Lorelei", "Lorenzo", "Louis", "Luca", "Lucas", "Lucca", "Lucia", "Lucian", "Luciana", "Luciano", "Lucille", "Lucy", "Luis", "Luka", "Lukas", "Luke", "Luna", "Luz", "Lydia", "Lyla", "Lylah", "Lyric", "Mabel", "Macey", "Maci", "Macie", "Mack", "Mackenzie", "Macy", "Madalyn", "Madalynn", "Madden", "Maddison", "Maddox", "Madeleine", "Madeline", "Madelyn", "Madelynn", "Madilyn", "Madilynn", "Madison", "Madisyn", "Madyson", "Mae", "Maeve", "Maggie", "Magnolia", "Magnus", "Maia", "Maison", "Major", "Makai", "Makayla", "Makena", "Makenna", "Makenzie", "Makhi", "Malachi", "Malakai", "Malaya", "Malaysia", "Malcolm", "Maleah", "Malia", "Maliah", "Malik", "Maliyah", "Mallory", "Manuel", "Mara", "Marc", "Marcel", "Marcelo", "Marco", "Marcos", "Marcus", "Margaret", "Margot", "Maria", "Mariah", "Mariam", "Mariana", "Marianna", "Marie", "Marilyn", "Marina", "Mario", "Marisol", "Marissa", "Mariyah", "Marjorie", "Mark", "Markus", "Marlee", "Marleigh", "Marley", "Marlon", "Marquis", "Marshall", "Martha", "Martin", "Marvin", "Mary", "Maryam", "Mason", "Mateo", "Mathew", "Mathias", "Matias", "Matilda", "Matteo", "Matthew", "Matthias", "Maurice", "Mauricio", "Maverick", "Max", "Maxim", "Maximilian", "Maximiliano", "Maximo", "Maximus", "Maxton", "Maxwell", "Maya", "Mayson", "Mckayla", "Mckenna", "Mckenzie", "Mckinley", "Meadow", "Megan", "Mekhi", "Melanie", "Melany", "Melina", "Melissa", "Melody", "Melvin", "Memphis", "Mercedes", "Mercy", "Meredith", "Messiah", "Mia", "Miah", "Micah", "Michael", "Michaela", "Micheal", "Michelle", "Miguel", "Mikaela", "Mikayla", "Mike", "Mila", "Milan", "Milana", "Milania", "Milena", "Miles", "Miley", "Miller", "Millie", "Milo", "Mina", "Mira", "Miracle", "Miranda", "Miriam", "Misael", "Mitchell", "Miya", "Moises", "Mollie", "Molly", "Monica", "Monroe", "Morgan", "Moriah", "Moses", "Moshe", "Mustafa", "Mya", "Myah", "Myla", "Myles", "Myra", "Nadia", "Nahla", "Nancy", "Naomi", "Nash", "Nasir", "Natalee", "Natalia", "Natalie", "Nataly", "Natalya", "Natasha", "Nathalie", "Nathaly", "Nathan", "Nathanael", "Nathaniel", "Nayeli", "Nehemiah", "Neil", "Nelson", "Neriah", "Nevaeh", "Neymar", "Nia", "Nicholas", "Nickolas", "Nico", "Nicolas", "Nicole", "Niels", "Niko", "Nikola", "Nikolai", "Nikolas", "Nina", "Nixon", "Noah", "Noe", "Noel", "Noelle", "Noemi", "Nola", "Nolan", "Nora", "Norah", "Nova", "Nyla", "Nylah", "Oakley", "Odin", "Olive", "Oliver", "Olivia", "Omar", "Omari", "Orion", "Orlando", "Oscar", "Osvaldo", "Otto", "Owen", "Pablo", "Paige", "Paislee", "Paisley", "Paityn", "Paloma", "Paola", "Paris", "Parker", "Patience", "Patricia", "Patrick", "Paul", "Paula", "Paulina", "Paxton", "Payton", "Pearl", "Pedro", "Penelope", "Penny", "Perla", "Peter", "Peyton", "Philip", "Phillip", "Phoebe", "Phoenix", "Pierce", "Pierre", "Piper", "Porter", "Presley", "Preston", "Prince", "Princess", "Princeton", "Priscilla", "Quentin", "Quincy", "Quinn", "Quintin", "Quinton", "Rachel", "Radia", "Raegan", "Raelyn", "Raelynn", "Rafael", "Raiden", "Raina", "Ramiro", "Ramon", "Randall", "Randy", "Rank", "Raphael", "Raquel", "Rashad", "Raul", "Raven", "Ray", "Rayan", "Rayden", "Raylan", "Raymond", "Rayna", "Rayne", "Reagan", "Rebecca", "Rebekah", "Reece", "Reed", "Reese", "Regan", "Regina", "Reginald", "Reid", "Remi", "Remington", "Remy", "Renata", "Rene", "Renee", "Reuben", "Rex", "Rey", "Reyna", "Rhett", "Rhys", "Ricardo", "Richard", "Ricky", "Rihanna", "Riley", "River", "Rivka", "Rob", "Robert", "Roberto", "Rocco", "Rocky", "Rodney", "Rodolfo", "Rodrigo", "Rogelio", "Roger", "Rohan", "Roland", "Rolando", "Roman", "Romeo", "Ronald", "Ronan", "Ronin", "Ronnie", "Rory", "Rosa", "Rosalie", "Rosalind", "Rosalyn", "Rose", "Roselyn", "Rosemary", "Rosie", "Rowan", "Rowen", "Roxanne", "Roy", "Royal", "Royce", "Ruben", "Ruby", "Rudy", "Russell", "Ruth", "Ryan", "Ryann", "Ryder", "Ryker", "Rylan", "Ryland", "Rylee", "Ryleigh", "Rylie", "Sabrina", "Sadie", "Sage", "Saige", "Salma", "Salvador", "Salvatore", "Sam", "Samantha", "Samara", "Samir", "Samiyah", "Samson", "Samuel", "Sandra", "Saniya", "Saniyah", "Santana", "Santiago", "Santino", "Santos", "Sara", "Sarah", "Sarahi", "Sarai", "Sariah", "Sasha", "Saul", "Savanna", "Savannah", "Sawyer", "Saylor", "Scarlet", "Scarlett", "Scarlette", "Scott", "Seamus", "Sean", "Sebastian", "Selah", "Selena", "Semaj", "Serena", "Serenity", "Sergio", "Seth", "Shane", "Shannon", "Sharon", "Shaun", "Shawn", "Shayla", "Shelby", "Sherlyn", "Shiloh", "Sidney", "Siena", "Sienna", "Sierra", "Silas", "Simon", "Simone", "Sincere", "Sky", "Skye", "Skyla", "Skylar", "Skyler", "Sloan", "Sloane", "Sofia", "Solomon", "Sonia", "Sonny", "Sophia", "Sophie", "Soren", "Spencer", "Stanley", "Stefan", "Stella", "Stephanie", "Stephen", "Sterling", "Stetson", "Steve", "Steven", "Sullivan", "Summer", "Susan", "Sutton", "Sydney", "Sylas", "Sylvia", "Tabitha", "Talia", "Taliyah", "Talon", "Tamia", "Tanner", "Tara", "Taryn", "Tate", "Tatiana", "Tatum", "Taylor", "Teagan", "Tegan", "Temperance", "Tenley", "Teresa", "Terrance", "Terrell", "Terrence", "Terry", "Tess", "Tessa", "Thaddeus", "Thalia", "Thatcher", "Theo", "Theodore", "Thiago", "Thomas", "Tiana", "Tiffany", "Timothy", "Tinley", "Titan", "Titus", "Tobias", "Toby", "Todd", "Tomas", "Tommy", "Tony", "Tori", "Trace", "Travis", "Trent", "Trenton", "Trevor", "Trey", "Trinity", "Tripp", "Tristan", "Tristen", "Tristian", "Tristin", "Triston", "Troy", "Truman", "Tucker", "Turner", "Ty", "Tyler", "Tyree", "Tyrell", "Tyrone", "Tyson", "Ulises", "Uriah", "Uriel", "Urijah", "Valentin", "Valentina", "Valentino", "Valeria", "Valerie", "Van", "Vance", "Vanessa", "Vaughn", "Vera", "Veronica", "Vicente", "Victor", "Victoria", "Vihaan", "Vincent", "Vincenzo", "Violet", "Virginia", "Vivian", "Viviana", "Vivienne", "Wade", "Walker", "Walter", "Warren", "Waylon", "Wayne", "Wendy", "Werner", "Wesley", "Westin", "Weston", "Whitney", "Will", "Willa", "William", "Willie", "Willow", "Wilson", "Winston", "Winter", "Wren", "Wyatt", "Wynter", "Xander", "Xavi", "Xavier", "Ximena", "Xzavier", "Yadiel", "Yael", "Yahir", "Yair", "Yamileth", "Yareli", "Yaretzi", "Yaritza", "Yasmin", "Yosef", "Yousef", "Yusuf", "Zachariah", "Zachary", "Zackary", "Zahra", "Zaid", "Zaiden", "Zain", "Zainab", "Zaire", "Zander", "Zane", "Zaniyah", "Zara", "Zaria", "Zariah", "Zariyah", "Zavier", "Zayden", "Zayn", "Zayne", "Zechariah", "Zeke", "Zion", "Zoe", "Zoey", "Zoie", "Zuri"]

def Adverb():
    return random.choice(adverbs)

def Adjective():
    return random.choice(adjectives)

def Name():
    return random.choice(names)

def Generate(words, separator):
    if words == 1:
        return Name()
    elif words == 2:
        return Adjective() + separator + Name()
    petname = []
    for i in range(0, words - 2):
        petname.append(Adverb())
    petname.append(Adjective())
    petname.append(Name())
    return separator.join(petname)
